powered by
List of data frames of all longitudinal parameters. Each data frame contains Monte Carlo samples for each antibody type.
campylobacterDelftParams4
A list of three dataframes:
IgA
A dataframe containing 3000 rows with 7 parameters for IgA antibody.
IgM
A dataframe containing 3000 rows with 7 parameters for IgM antibody.
IgG
A dataframe containing 3000 rows with 7 parameters for IgG antibody.
# NOT RUN { # Show first rows of every dataframe contained in campylobacterDelftParams4 lapply(campylobacterDelftParams4, head) # }
Run the code above in your browser using DataLab