Learn R Programming

seroincidence (version 2.0.0)

campylobacterSSIParams1: Campylobacter SSI Response Parameters Data for Model 1

Description

List of data frames of all longitudinal parameters. Each data frame contains Monte Carlo samples for each antibody type

Usage

campylobacterSSIParams1

Arguments

Format

A list of three dataframes:

IgA

A dataframe containing 4000 rows with 7 parameters for IgA antibody.

IgM

A dataframe containing 4000 rows with 7 parameters for IgM antibody.

IgG

A dataframe containing 4000 rows with 7 parameters for IgG antibody.

Examples

Run this code
# NOT RUN {
# Show first rows of every dataframe contained in campylobacterSSIParams1
lapply(campylobacterSSIParams1, head)

# }

Run the code above in your browser using DataLab