Learn R Programming

seroincidence (version 2.0.0)

pertussisIgGPTParams1: Pertussis IgG-PT Response Parameters Data for Model 1

Description

List of data frames of all longitudinal parameters. Each data frame contains Monte Carlo samples for each antibody type.

Usage

pertussisIgGPTParams1

Arguments

Format

A dataframe IgG containing 3000 rows with 7 parameters for IgG antibody.

Examples

Run this code
# NOT RUN {
# Show first rows of every dataframe contained in pertussisIgGPTParams1
lapply(pertussisIgGPTParams1, head)

# }

Run the code above in your browser using DataLab