Learn R Programming

seroincidence (version 2.0.0)

print.summary.seroincidence: Print Method for Seroincidence Summary Object

Description

Custom print function to show output of the seroincidence summary summary.seroincidence.

Usage

# S3 method for summary.seroincidence
print(x, ...)

Arguments

x

A list containing output of function summary.seroincidence.

...

Additional arguments affecting the summary produced.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
# estimate seroincidence
seroincidence <- estimateSeroincidence(...)

# calculate summary statistics for the seroincidence object
seroincidenceSummary <- summary(seroincidence)

# print the summary of seroincidence object to the console
print(seroincidenceSummary)

# or simply type (appropriate print method will be invoked automatically)
seroincidenceSummary
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab