powered by
List of data frames of all longitudinal parameters. Each data frame contains Monte Carlo samples for each antibody type.
pertussisIgGPTParams1
A dataframe IgG containing 3000 rows with 7 parameters for IgG antibody.
IgG
# NOT RUN { # Show first rows of every dataframe contained in pertussisIgGPTParams1 lapply(pertussisIgGPTParams1, head) # }
Run the code above in your browser using DataLab