powered by
List of data frames of all longitudinal parameters. Each data frame contains Monte Carlo samples for each antibody type.
pertussisIgGPTParams2
A dataframe IgG containing 3000 rows with 7 parameters for IgG antibody.
IgG
# NOT RUN { # Show first rows of every dataframe contained in pertussisIgGPTParams2 lapply(pertussisIgGPTParams2, head) # }
Run the code above in your browser using DataLab